@@ -136,7 +136,7 @@ def url_info(url, faker = False):
         type = None
         if headers['content-disposition']:
             try:
-                filename = parse.unquote(r1(r'filename="?(.+)"?', headers['content-disposition']))
+                filename = parse.unquote(r1(r'filename="?([^"]+)"?', headers['content-disposition']))
                 if len(filename.split('.')) > 1:
                     ext = filename.split('.')[-1]
                 else:
